"""meteoswiss - Library to get data from meteo swiss"""

__version__ = "0.2.5"
__author__ = "websylv <div@webhu.org>"
__all__ = ["meteoSwissClient", "StationType"]

from .client import meteoSwissClient, StationType
